@@ -20,7 +20,7 @@ use WWW::Mechanize;
 use JSON;
 use Try::Tiny;
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 has url => (
     is       => 'rw',
@@ -72,7 +72,7 @@ sub _get_commands {
                 url      => $name . '/' . $action->{key},
                 internal => !!$action->{internal},
                 post     => !!$action->{post},
-                description => $action->{description} || '',
+                description => $action->{description},
             };
         }
     }
@@ -88,6 +88,8 @@ sub AUTOLOAD {
     $api =~ s{.*::}{};
     $api =~ s{_}{/}g;
 
+    return if $api eq 'DESTROY';
+
     if (!$self->commands->{$api}) {
         confess "Unknown command $api for SonarQube " . $self->version . '!';
     }
@@ -156,7 +158,7 @@ WebService::SonarQube - API for talking to SonarQube
 
 =head1 VERSION
 
-This documentation refers to WebService::SonarQube version 0.07
+This documentation refers to WebService::SonarQube version 0.08
 
 =head1 SYNOPSIS
 
